package org.cpas.prime;

// Les composants associs, http://compoasso.free.fr/primelistweb
//
// Lanceur des tests sur la division euclidienne
public class EuclideBench {

	private final static int MAX_TEST_CASE = 20000000;

	public static void main(String[] args) {

		IEuclide naive = new EuclideNaive();
		IEuclide decimale = new EuclideDecimale();
		IEuclide dichotomieBinaire = new EuclideDichotomieBinaire();
		IEuclide egyptienneBinaire = new EuclideEgyptienneBinaire();
		IEuclide binaire = new EuclideBinaire();

		EuclideTestCaseGenerator generator = new EuclideTestCaseGenerator(MAX_TEST_CASE);

		long[][] testCase = generator.aleatoire();
		testEuclide(naive, testCase);
		testEuclide(decimale, testCase);
		testEuclide(dichotomieBinaire, testCase);
		testEuclide(egyptienneBinaire, testCase);
		testEuclide(binaire, testCase);

		testCase = null;
		System.out.println();

		testCase = generator.aGtB();
		testEuclide(naive, testCase);
		testEuclide(decimale, testCase);
		testEuclide(dichotomieBinaire, testCase);
		testEuclide(egyptienneBinaire, testCase);
		testEuclide(binaire, testCase);

		testCase = null;
		System.out.println();

		testCase = generator.custom();
		testEuclide(naive, testCase);
		testEuclide(decimale, testCase);
		testEuclide(dichotomieBinaire, testCase);
		testEuclide(egyptienneBinaire, testCase);
		testEuclide(binaire, testCase);
	}

	private static void testEuclide(IEuclide euclideMethod, long[][] testCase) {
		long debut = System.currentTimeMillis();

		long check = 0;
		for (int i = 0; i < MAX_TEST_CASE; i++) {
			long[] u = euclideMethod.euclide(testCase[0][i], testCase[1][i]);
			check += u[0];
		}

		long fin = System.currentTimeMillis();
		System.out.println("Euclide " + euclideMethod.getName() + " T: " + (fin - debut) / 1000d
				+ " -- verification " + check);
	}
}
